@@ -12,24 +12,24 @@ def udpate_os_path():
     """Update PATH env variable to find linters."""
     script_path = Path(__file__).resolve()
     os.environ["PATH"] = "".join(
-        (str(script_path.parent), os.pathsep, os.environ["PATH"])
+        (str(script_path.parent), os.pathsep, os.environ["PATH"]),
     )
 
     # replace /lib/ with /bin/, and add to PATH
     for parent in reversed(script_path.parents):
         if parent.stem == "lib":
             os.environ["PATH"] = "".join(
-                (str(parent.parent / "bin"), os.pathsep, os.environ["PATH"])
+                (str(parent.parent / "bin"), os.pathsep, os.environ["PATH"]),
             )
 
 
 def main():
     """Entry point."""
     parser = argparse.ArgumentParser(
-        description="Python formatter combining existing formatters"
+        description="Python formatter combining existing formatters",
     )
     parser.add_argument(
-        "file", metavar="FILE", type=str, help="path of the file to format"
+        "file", metavar="FILE", type=str, help="path of the file to format",
     )
     parser.add_argument(
         "--quiet",
@@ -55,12 +55,9 @@ def main():
         print(
             "".join(
                 difflib.unified_diff(
-                    orig_content,
-                    copy_content,
-                    fromfile="origin",
-                    tofile="formatted",
-                )
-            )
+                    orig_content, copy_content, fromfile="origin", tofile="formatted",
+                ),
+            ),
         )
         Path(copy_file).unlink()
     else:
